@@ -3,6 +3,7 @@ use hal::pac;
 use hal::prelude::*;
 use hal::pwr;
 use hal::rcc;
+use hal::rcc::rec::AdcClkSel;
 use hal::time::Hertz;
 use hal::time::MegaHertz;
 
@@ -47,7 +48,7 @@ pub fn configure(pwr: pwr::Pwr, rcc: rcc::Rcc, syscfg: &pac::SYSCFG) -> rcc::Ccd
     let pwrcfg = pwr.vos0(syscfg).freeze();
 
     #[cfg(not(feature = "log-itm"))]
-    let ccdr = rcc
+    let mut ccdr = rcc
         .use_seed_crystal() // high speed external crystal @ 16 MHz
         .pll1_strategy(rcc::PllConfigStrategy::Iterative) // pll1 drives system clock
         .sys_ck(480.MHz()) // system clock @ 480 MHz
@@ -56,7 +57,7 @@ pub fn configure(pwr: pwr::Pwr, rcc: rcc::Rcc, syscfg: &pac::SYSCFG) -> rcc::Ccd
         .freeze(pwrcfg, syscfg);
 
     #[cfg(any(feature = "log-itm"))]
-    let ccdr = rcc
+    let mut ccdr = rcc
         .use_seed_crystal() // high speed external crystal @ 16 MHz
         .pll1_strategy(rcc::PllConfigStrategy::Iterative) // pll1 drives system clock
         .sys_ck(480.MHz()) // system clock @ 480 MHz
@@ -65,6 +66,9 @@ pub fn configure(pwr: pwr::Pwr, rcc: rcc::Rcc, syscfg: &pac::SYSCFG) -> rcc::Ccd
         .per_ck(4.MHz()) // peripheral clock @ 4 MHz
         .freeze(pwrcfg, syscfg);
 
+    // switch adc_ker_ck_input multiplexer to per_ck
+    ccdr.peripheral.kernel_adc_clk_mux(AdcClkSel::PER);
+
     // enable itm support
     #[cfg(any(feature = "log-itm"))]
     unsafe {
@@ -75,7 +79,7 @@ pub fn configure(pwr: pwr::Pwr, rcc: rcc::Rcc, syscfg: &pac::SYSCFG) -> rcc::Ccd
             &mut cp.DCB,
             &dp.DBGMCU,
             &mut cp.ITM,
-            ccdr.clocks.c_ck().0,
+            ccdr.clocks.c_ck().to_Hz(),
             swo_frequency,
         );
     }
